@@ -130,12 +130,16 @@ class Excel:
 
         return writer.book.sheetnames
 
-    def insert_image(self, filename: str, imagename: str, sheet_name: str) -> None:
+    def insert_image(self, filename: str, imagename: str, sheet_name: str, cell: str='A1') -> None:
         writer = pd.ExcelWriter(filename, engine='openpyxl', mode='a')
 
-        # try to open an existing workbook
-        writer.book = load_workbook(filename)
-
-        sheet = writer.book.sheetnames[sheet_name]
+        sheet = None
+        for i, sheetname in enumerate(writer.book.sheetnames):
+            if sheet_name == sheetname:
+                sheet = writer.book.worksheets[i]
+                break
+        if sheet is None:
+            sheet = writer.book.create_sheet(sheet_name, writer.book.sheetnames)
+        
         picture = openpyxl.drawing.image.Image(imagename)
-        sheet.add_image(picture, 'A1')
\ No newline at end of file
+        sheet.add_image(picture, cell)
\ No newline at end of file
